@@ -3,6 +3,8 @@ knitr::opts_chunk$set(comment = "")
 library(gpg)
 options(width = 120, max.print = 100)
 
+is_ci <- nchar(Sys.getenv("CI")) > 0
+
 gpg_list_keys <- function(...){
   gpg::gpg_list_keys(...)[c("id", "name", "email")]
 }
@@ -10,7 +12,7 @@ gpg_list_keys <- function(...){
 ## ---------------------------------------------------------------------------------------------------------------------
 str(gpg_info())
 
-## ---------------------------------------------------------------------------------------------------------------------
+## ---- eval = !is_ci---------------------------------------------------------------------------------------------------
 gpg_restart(home = tempdir())
 
 ## ---------------------------------------------------------------------------------------------------------------------
